@@ -1,4 +1,10 @@
-from django.utils.translation import ugettext_lazy as _
+import django
+
+__version__ = django.get_version()
+if __version__.startswith("2"):
+    from django.utils.translation import ugettext_lazy as _
+else:
+    from django.utils.translation import gettext_lazy as _
 
 
 class CustomVariable(object):
@@ -15,7 +21,7 @@ class CustomVariable(object):
         for field in ["name", "description", "key"]:
             if not getattr(self, field, None):
                 raise ValueError(
-                    f"A CustomVariable class has to provide a '{field}' value."
+                    "A CustomVariable class has to provide a '{}' value.".format(field)
                 )
 
     def as_dict(self):
